#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-pdm-pep517%{psuffix}
Version:        1.1.2
Release:        2.3
Summary:        Python Development Master
License:        MIT
URL:            https://github.com/pdm-project/pdm-pep517
Source:         https://files.pythonhosted.org/packages/source/p/pdm-pep517/pdm-pep517-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pdm-pep517 = %{version}}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  git-core
%endif
# /SECTION
%python_subpackages

%description
PDM is a modern Python package manager with PEP 582 support. It
installs and manages packages in a similar way to npm that
doesn't need to create a virtualenv at all!

%prep
%autosetup -p1 -n pdm-pep517-%{version}

%build
%if !%{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# must be set to the same value as it is set by the python_flavored_alternatives macro used below in pytest
export XDG_CONFIG_HOME=$PWD/build/xdgflavorconfig
%{python_expand # the config home is inside the shuffled build dir
mkdir -p $XDG_CONFIG_HOME/git
touch $XDG_CONFIG_HOME/git/config
git config --global user.name abuild
git config --global user.email abuild@obs
}
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%dir %{python_sitelib}/pdm
%{python_sitelib}/pdm/pep517
%{python_sitelib}/pdm_pep517-%{version}.dist-info
%endif

%changelog
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Feb 17 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 1.1.2
  * fix: raise an error if dynamic version config is missing
  * feat: support specifying zipinfo date via env var
  * updated vendored packaging
* Tue Dec  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.0.6
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #128
  * Add setuptools to dev dependencies by @frenzymadness in #131
  * feat: Honor the metadata_directory passed to build_wheel by @frostming in #132
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.0.5
  * README.md: Fix Dynamic Version example by @hosiet in #115
  * Support license files located in subdirectories by @crai0 in #119
  * fix: update implementation of PEP 639 by @frostming in #120
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #121
  * feat: expand vars in req url by @frostming in #127
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #124
  * tests: Configure git for scm tests by @stanislavlevin in #126
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.0.4
  Bug Fixes
  Fix a bug of editable install not reading run-setuptools = false config. #107
  Put the long description in the body as specified by Metadata Version 2.1 #109
  Overwrite the existing files in the custom build stage of WheelBuilder. #114
* Wed Aug  3 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.0.3
  * Fix a bug of editable install not reading
  `run-setuptools = false` config.
  * Put the long description in the body as specified by Metadata
    Version 2.1
  * Use `pkgutil`-style namespace package
- Remove unnecessary build requirements
- Remove release tools from test requirements
- Requires python-devel only for tests
- Fix missing psuffix in test multibuild flavor
- Unskip git based tests
* Tue Aug  2 2022 Torsten Gruner <simmphonie@opensuse.org>
- Update to 1.0.2
  * Ensure the license is a file. Also add LICENSES/* to the default
    search patterns, as specified by REUSE spec. #105
  * Throw a better error message when a malformed requirement
    is being parsed. #106
- Release v1.0.1 (2022-07-03)
  * Fix a compatibility issue that run_setuptools defaults to True
    for old build configuration.
- Release v1.0.0 (2022-06-25)
  * No significant changes.
- Release v1.0.0a1 (2022-06-22)
  * Emit UserWarning for deprecated settings.
- Release v1.0.0a0 (2022-06-22)
  * Allow writing dynamic version from scm source to a file. #94
  * The dynamic version table fields are renamed: {from = ...} to
    {source = "file", path = ...} and {use_scm = true} to {source = "scm"}. #95
  * Support custom build script, a script containing a function named build
    that takes (src, dst) as the arguments. When run-setuptools is true, the
    build function will be called in a generated setup.py file, with the setup
    parameters as the only argument. #98
  * Removals and Deprecations
    + includes, excludes, source-includes, package-dir, is-purelib, editable-backend
    are moved to [tool.pdm.build] table. build field is renamed to setup-script
    under [tool.pdm.build] table. #96
* Wed Jun 15 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.12.7:
  * Allow overriding SCM version with env var. This is useful to build
    from a source tree without SCM. #89
  * Fallback the README content type to text/plain if no suffix is given. #85
  * Write license files when preparing metadata for wheels. #86
  * Do not emit deprecation warnings for license field until PEP 639 is
    accepted.
  * Warn about editable not being available for PEP 420 namespace packages. #79
  * Construct RECORD file using csv.writer to ensure correct quoting on
    path for each entry. #80
  * Don't validate license text for PEP 621 license field for now. #78
  * Implement PEP 639: Improving License Clarity in Project Metadata #76
  * Mandates the PEP 621 metadata and raise an error if invalid. #76
  * Release v0.11.2 (2022-02-11)
  * Change the default editable-backend to path until editables backend is
    stable.
  * Fix a bug that version can't be parsed if it is followed by a comment. #75
  * Drop the support for Python < 3.7. #72
  * Show meaningful error message when version isn't found in the specified
    file. #73
  * Preserve the file mode when building a wheel, also correct the
    datetime. #69
  * Use alternatives to replace the deprecated usage of distutils. #69
* Thu Jan 20 2022 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for pdm-pep517 0.10.1.
